use std::env;
use std::fs::File;
use std::path::Path;

use nbt::{Blob, Value, Map};

fn read_nbt(path_str: String) -> Option<Blob> {
    let path_to_dat = Path::new(&path_str);

    if let Ok(mut file) = File::open(path_to_dat) {
        Some(Blob::from_gzip_reader(&mut file).expect("invalid nbt format"))
    } else {
        None
    }
}

fn main() {
    let nbt_blob = read_nbt(env::args().take(2).nth(1).expect("pls call with .dat")).expect("unable to read nbt");


    print_value_map(&nbt_blob.content, &0);
}

fn print_value_map(map: &Map<String, Value>, level: &usize) {
    for (key, value) in map.iter() {
        match value {
            Value::Compound(inner_map) => {
                print_formatted_key(key, level);
                print_value_map(inner_map, &(*level + 1));
            },
            _ => print_formatted_key(key, level)
        }
    }
}

fn print_formatted_key(key: &str, level: &usize) {
    println!("{space:>count$}{name}", space="", count=*level*4, name=key)
}
